package org.fuseri.moduleexercise.answer;

import org.fuseri.moduleexercise.common.DomainRepositoryImpl;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * An implementation of the AnswerRepository interface
 * Provides access to Answer entities stored in a data source
 */
@Repository
public class AnswerRepositoryImpl extends DomainRepositoryImpl<Answer, String> implements AnswerRepository {

    /**
     * Find all answers to a question with the specified ID
     *
     * @param questionId the ID of the question to find answers for
     * @return a list of all answers to the specified question
     */
    @Override
    public List<Answer> findByQuestionId(String questionId) {
        return getItems()
                .stream()
                .filter(e -> e.getQuestionId().equals(questionId))
                .toList();
    }
}
