package org.fuseri.moduleexercise.answer;

import lombok.Getter;
import org.fuseri.moduleexercise.common.DomainService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * Represent a service for managing Answer entities
 */
@Service
public class AnswerService extends DomainService<Answer> {

    /**
     * The repository instance used by this service
     */
    @Getter
    private final AnswerRepository repository;

    /**
     * Construct a new instance of AnswerService with the specified repository
     *
     * @param repository the repository instance to be used by this service
     */
    @Autowired
    public AnswerService(AnswerRepository repository) {
        this.repository = repository;
    }

    /**
     * Retrieve a list of Answer entities with the specified question ID
     *
     * @param questionId the ID of the question to retrieve answers for
     * @return a list of Answer entities with the specified question ID
     */
    @Transactional(readOnly = true)
    public List<Answer> findAllByQuestionId(String questionId) {
        return repository.findByQuestionId(questionId);
    }

}
