package org.fuseri.moduleexercise.common;

/**
 * Represent common service for managing entities
 *
 * @param <T> the type of entity managed by this service
 */
public abstract class DomainService<T extends DomainObject> {

    /**
     * The default page size used for pagination
     */
    public static final int DEFAULT_PAGE_SIZE = 10;

    /**
     * Return the repository used by this service
     *
     * @return the repository used by this service
     */
    public abstract DomainRepository<T, String> getRepository();

    /**
     * Create an entity by saving it to the repository
     *
     * @param entity the entity to create
     * @return the created entity
     */
    public T create(T entity) {
        return getRepository().save(entity);
    }
}